@@ -56,6 +56,7 @@ import static org.apache.commons.lang.StringUtils.isNotEmpty;
 import java.io.File;
 import java.io.IOException;
 import java.lang.reflect.Array;
+import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.SQLException;
 import java.sql.Types;
@@ -69,8 +70,10 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.exception.OXException;
 import com.openexchange.imageconverter.api.FileItemException;
 
@@ -404,13 +407,50 @@ public class FileItemUtils {
         return ret;
     }
 
+    /**
+     * @param sleepTimeMillis
+     */
+    public static void sleepThread(final long sleepTimeMillis) {
+        try {
+            Thread.sleep(sleepTimeMillis);
+        } catch (InterruptedException e) {
+            // ok
+        }
+    }
+
+    /**
+     * @param con
+     * @param sqlException
+     * @param cause
+     * @throws FileItemException
+     */
+    public static void handleException(@Nullable final Connection con, @NonNull final Exception exception, int sleepTimeout, @Nullable String cause) throws FileItemException {
+        if (null != con) {
+            try {
+                // perform transaction rollback first
+                con.rollback();
+            } catch (@SuppressWarnings("unused") SQLException e) {
+                // not interested in
+            }
+        }
+
+        // reschedule in case of a transaction deadlock
+        if ((exception instanceof SQLException) && ((SQLException) exception).getErrorCode() == 1213) {
+			FileItemUtils.sleepThread(sleepTimeout);
+		} else {
+            throw isEmpty(cause) ?
+                new FileItemException(exception) :
+                    new FileItemException(cause, exception);
+        }
+    }
+
     // - Logging ---------------------------------------------------------------
 
     /**
      * @return
      */
     public static boolean isLogError() {
-        return implGetLogger().isErrorEnabled();
+        return LOG.isErrorEnabled();
     }
 
     /**
@@ -418,7 +458,7 @@ public class FileItemUtils {
      */
     public static void logError(final String msg) {
         if (isNotEmpty(msg)) {
-            implGetLogger().error(msg);
+            LOG.error(msg);
         }
     }
 
@@ -426,7 +466,7 @@ public class FileItemUtils {
      * @return
      */
     public static boolean isLogWarn() {
-        return implGetLogger().isWarnEnabled();
+        return LOG.isWarnEnabled();
     }
 
     /**
@@ -434,7 +474,7 @@ public class FileItemUtils {
      */
     public static void logWarn(final String msg) {
         if (isNotEmpty(msg)) {
-            implGetLogger().warn(msg);
+            LOG.warn(msg);
         }
     }
 
@@ -442,7 +482,7 @@ public class FileItemUtils {
      * @return
      */
     public static boolean isLogInfo() {
-        return implGetLogger().isInfoEnabled();
+        return LOG.isInfoEnabled();
     }
 
     /**
@@ -450,7 +490,7 @@ public class FileItemUtils {
      */
     public static void logInfo(final String msg) {
         if (isNotEmpty(msg)) {
-            implGetLogger().info(msg);
+            LOG.info(msg);
         }
     }
 
@@ -458,7 +498,7 @@ public class FileItemUtils {
      * @return
      */
     public static boolean isLogDebug() {
-        return implGetLogger().isDebugEnabled();
+        return LOG.isDebugEnabled();
     }
 
     /**
@@ -466,7 +506,7 @@ public class FileItemUtils {
      */
     public static void logDebug(final String msg) {
         if (isNotEmpty(msg)) {
-            implGetLogger().debug(msg);
+            LOG.debug(msg);
         }
     }
 
@@ -474,7 +514,7 @@ public class FileItemUtils {
      * @return
      */
     public static boolean isLogTrace() {
-        return implGetLogger().isTraceEnabled();
+        return LOG.isTraceEnabled();
     }
 
     /**
@@ -482,7 +522,7 @@ public class FileItemUtils {
      */
     public static void logTrace(final String msg) {
         if (isNotEmpty(msg)) {
-            implGetLogger().trace(msg);
+            LOG.trace(msg);
         }
     }
 
@@ -491,7 +531,7 @@ public class FileItemUtils {
      */
     public static void logTrace(final String msg, final Throwable e) {
         if (isNotEmpty(msg)) {
-            implGetLogger().trace(msg, e);
+            LOG.trace(msg, e);
         }
     }
 
@@ -499,7 +539,7 @@ public class FileItemUtils {
      * @param e
      */
     public static void logExcp(Throwable e) {
-        if (implGetLogger().isErrorEnabled()) {
+        if (LOG.isErrorEnabled()) {
             String msg = null;
 
             if (null != e) {
@@ -520,18 +560,14 @@ public class FileItemUtils {
                 msg = DEF_EXCEPTION_MSG;
             }
 
-            implGetLogger().error(msg);
+            LOG.error(msg);
         }
     }
 
-    // - Implementation --------------------------------------------------------
-
-    static Logger implGetLogger() {
-        return FileItemService.getLogger();
-    }
-
     // - Statics ---------------------------------------------------------------
 
+    final public static Logger LOG = LoggerFactory.getLogger(FileItemService.class);
+
     final private static AtomicBoolean IS_TERMINATED = new AtomicBoolean(false);
 
     final private static  String DEF_EXCEPTION_MSG = "Unspecified FileItemService exception occured";
