@@ -160,6 +160,20 @@ public final class ImageConverter implements IImageConverter {
         }
     }
 
+    /**
+     * @return
+     */
+    public boolean isRunning() {
+        return m_running.get();
+    }
+
+    /**
+     * @return
+     */
+    public ImageProcessor.ImageProcessorStatus getImageProcessorStatus() {
+        return m_queue.getImageProcessorStatus();
+    }
+
     // - IImageConverter ----------------------------------------------------------
 
     /*
@@ -350,7 +364,7 @@ public final class ImageConverter implements IImageConverter {
                 }
             }
         } catch (IOException | ImageConverterException e) {
-            LOG.trace("IC exception while caching and getting Image" ,e);
+            LOG.trace("IC exception while caching and getting Image",e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw new ImageConverterException("IC error while caching and getting image: " + imageKey, e);
@@ -545,21 +559,21 @@ public final class ImageConverter implements IImageConverter {
     /**
      * @return
      */
-    ImageFormat[] getImageFormats() {
+    public ImageFormat[] getImageFormats() {
         return m_imageFormats;
     }
 
     /**
      * @return
      */
-    IFileItemService getFileItemService() {
+    public IFileItemService getFileItemService() {
         return m_fileItemService;
     }
 
     /**
      * @return
      */
-    IMetadataReader getMetadataReader() {
+    public IMetadataReader getMetadataReader() {
         return m_metadataReader;
     }
 
@@ -567,7 +581,7 @@ public final class ImageConverter implements IImageConverter {
      * @return
      * @throws ImageConverterException
      */
-    long getKeyCount() throws ImageConverterException {
+    public long getKeyCount() throws ImageConverterException {
         try {
             return m_fileItemService.getSubGroupCount(ImageConverterUtils.IMAGECONVERTER_GROUPID);
         } catch (FileItemException e) {
@@ -578,7 +592,7 @@ public final class ImageConverter implements IImageConverter {
     /**
      * @return
      */
-    long getTotalImagesSize() throws ImageConverterException {
+    public long getTotalImagesSize() throws ImageConverterException {
         try {
             return m_fileItemService.getGroupLength(ImageConverterUtils.IMAGECONVERTER_GROUPID);
         } catch (FileItemException e) {
@@ -591,7 +605,7 @@ public final class ImageConverter implements IImageConverter {
      * @return
      * @throws ImageConverterException
      */
-    long getAvailableImagesSize(@Nullable final Properties searchProperties) throws ImageConverterException {
+    public long getAvailableImagesSize(@Nullable final Properties searchProperties) throws ImageConverterException {
         try {
             return m_fileItemService.getGroupLength(ImageConverterUtils.IMAGECONVERTER_GROUPID, searchProperties);
         } catch (FileItemException e) {
@@ -604,7 +618,7 @@ public final class ImageConverter implements IImageConverter {
      * @return
      * @throws ImageConverterException
      */
-    boolean isAvailable(@NonNull final String imageKey) throws ImageConverterException {
+    public boolean isAvailable(@NonNull final String imageKey) throws ImageConverterException {
         try {
             return m_fileItemService.containsSubGroup(ImageConverterUtils.IMAGECONVERTER_GROUPID, imageKey);
         } catch (FileItemException e) {
@@ -617,7 +631,7 @@ public final class ImageConverter implements IImageConverter {
      * @return
      * @throws ImageConverterException
      */
-    @NonNull String[] getAvailable(@Nullable final Properties searchProperties) throws ImageConverterException {
+    @NonNull public String[] getAvailable(@Nullable final Properties searchProperties) throws ImageConverterException {
         try {
             final Object[] foundObjs = (null != searchProperties) ?
                 m_fileItemService.get(ImageConverterUtils.IMAGECONVERTER_GROUPID, searchProperties) :
@@ -655,7 +669,7 @@ public final class ImageConverter implements IImageConverter {
      * @param context
      * @return
      */
-    void remove(@NonNull final String imageKey) throws ImageConverterException {
+    public void remove(@NonNull final String imageKey) throws ImageConverterException {
         // instantly move job to the highest priority queue,
         // since the current request needs to be handled ASAP
         if (m_running.get()) {
@@ -677,7 +691,7 @@ public final class ImageConverter implements IImageConverter {
      * @param imageKeys
      * @throws ImageConverterException
      */
-    void remove(@NonNull final Collection<String> imageKeysCollection) throws ImageConverterException {
+    public void remove(@NonNull final Collection<String> imageKeysCollection) throws ImageConverterException {
         if (!imageKeysCollection.isEmpty() && m_running.get()) {
             // remove all queued entries first
              imageKeysCollection.forEach((imageKey) -> m_queue.removeImageConverterJob(imageKey));
