@@ -108,15 +108,17 @@ public class ImageConverterCache extends Thread {
     */
    public void shutdown() {
        if (m_running.compareAndSet(true, false)) {
-           final long shutdownStartTimeMillis = System.currentTimeMillis();
+           final boolean info = LOG.isInfoEnabled();
+           long shutdownStartTimeMillis = 0;
 
-           if (LOG.isInfoEnabled()) {
+           if (info) {
                LOG.info("IC ImageConverterCache starting shutdown");
+               shutdownStartTimeMillis = System.currentTimeMillis();
            }
 
            interrupt();
 
-           if (LOG.isInfoEnabled()) {
+           if (info) {
                LOG.info(ImageConverterUtils.STR_BUILDER().
                    append("IC ImageConverterCache shutdown finished in ").
                    append(System.currentTimeMillis() - shutdownStartTimeMillis).append("ms").toString());
@@ -177,6 +179,12 @@ public class ImageConverterCache extends Thread {
      * @return
      * @throws ImageConverterException
      */
+    final private static String SQL_COUNT_BASED_QUERY = ImageConverterUtils.STR_BUILDER().
+        append("SELECT fc.FileStoreNumber, fc.FileStoreId, fc.SubGroupId, fc.FileId, MIN(fp.ModificationDate) AS KeyOldest").
+        append(" FROM Content_OX_IC fc INNER JOIN Properties_OX_IC fp ON fc.FileStoreNumber=fp.FileStoreNumber AND fc.FileStoreId=fp.FileStoreId").
+        append(" GROUP BY fc.SubGroupId, fc.FileId").
+        append(" ORDER BY KeyOldest ASC").toString();
+
     private int implRemoveObsoleteCountBasedKeys() throws ImageConverterException, FileItemException {
         int removedKeys = 0;
 
@@ -221,6 +229,11 @@ public class ImageConverterCache extends Thread {
      * @return
      * @throws ImageConverterException
      */
+    final private static String SQL_TIME_BASED_QUERY = ImageConverterUtils.STR_BUILDER().
+        append("SELECT fc.FileStoreNumber, fc.FileStoreId, fc.SubGroupId, fc.FileId, MIN(fp.ModificationDate) AS KeyOldest").
+        append(" FROM Content_OX_IC fc INNER JOIN Properties_OX_IC fp ON fc.FileStoreNumber=fp.FileStoreNumber AND fc.FileStoreId=fp.FileStoreId").
+        append(" WHERE fp.ModificationDate<=").toString();
+
     private int implRemoveObsoleteTimeBasedKeys() throws ImageConverterException, FileItemException {
         int removedKeys = 0;
 
@@ -264,6 +277,12 @@ public class ImageConverterCache extends Thread {
      * @return
      * @throws ImageConverterException
      */
+    final private static String SQL_SIZE_BASED_QUERY = ImageConverterUtils.STR_BUILDER().
+        append("SELECT fc.FileStoreNumber, fc.FileStoreId, fc.SubGroupId, fc.FileId, SUM(fp.Length) AS KeyLength, MIN(fp.ModificationDate) AS KeyOldest").
+        append(" FROM Content_OX_IC fc INNER JOIN Properties_OX_IC fp ON fc.FileStoreNumber=fp.FileStoreNumber AND fc.FileStoreId=fp.FileStoreId").
+        append(" GROUP BY fc.SubGroupId, fc.FileId").
+        append(" ORDER BY KeyOldest ASC").toString();
+
     private int implRemoveObsoleteSizeBasedKeys() throws ImageConverterException, FileItemException {
         int removedKeys = 0;
 
