@@ -151,7 +151,7 @@ public class ImageConverterConfig implements Closeable {
 
                     IMAGECONVERTER_ERROR_PATH = null;
 
-                    LOG.warn("IC is not able to create or write to specified error directory: " + errorPathStr);
+                    LOG.warn("IC is not able to create or write to specified error directory: {}", errorPathStr);
                 }
             }
 
@@ -173,6 +173,13 @@ public class ImageConverterConfig implements Closeable {
             // GrahicsMagick instead of ImageMagick?
             IMAGECONVERTER_USE_GRAPHICSMAGICK = configService.getBoolProperty("com.openexchange.imageconverter.imagemagick.useGraphicsMagick", false);
 
+            // Optional user comment for processed images
+            final String userCommentStr = configService.getProperty("com.openexchange.imageconverter.imagemagick.userComment");
+
+            if (StringUtils.isNotBlank(userCommentStr)) {
+                IMAGECONVERTER_IMAGE_USERCOMMENT = userCommentStr;
+            }
+
             try {
                 // max. cache size in GigaBytes
                 IMAGECONVERTER_CACHE_MAX_SIZE = Long.parseLong(configService.getProperty("com.openexchange.imageconverter.cache.maxSizeGB", "-1"));
@@ -252,7 +259,7 @@ public class ImageConverterConfig implements Closeable {
                 try {
                     FileUtils.cleanDirectory(IMAGECONVERTER_SPOOLPATH = targetDir);
                 } catch (@SuppressWarnings("unused") IOException e) {
-                    LOG.error("IC is not able to delete spool directory when shut down: " + IMAGECONVERTER_SPOOLPATH.toString());
+                    LOG.error("IC is not able to delete spool directory when shut down: {}", IMAGECONVERTER_SPOOLPATH.toString());
                 }
             }
         }
@@ -295,6 +302,12 @@ public class ImageConverterConfig implements Closeable {
      */
     public static boolean IMAGECONVERTER_USE_GRAPHICSMAGICK = false;
 
+    /**
+     * If set, the given String will be written as comment tag
+     * into image file while/when processing an image
+     */
+    public static String IMAGECONVERTER_IMAGE_USERCOMMENT = null;
+
     /**
      * The maximum amount of time to wait for an image
      * conversion process until it gets terminated
