@@ -74,7 +74,6 @@ import com.openexchange.imageconverter.api.FileItemException;
 import com.openexchange.imageconverter.api.IFileItem;
 import com.openexchange.imageconverter.api.IFileItemReadAccess;
 import com.openexchange.imageconverter.api.IFileItemService;
-import com.openexchange.imageconverter.api.IImageConverterMonitoring;
 import com.openexchange.imageconverter.api.IMetadata;
 import com.openexchange.imageconverter.api.IMetadataReader;
 import com.openexchange.imageconverter.api.ImageConverterException;
@@ -106,14 +105,14 @@ public class ImageConverterUtils {
     public static ImageConverter IC = null;
 
     /**
-     * IC_MONITOR
+     * IC_MBEAN
      */
-    public static ImageConverterMonitoring IC_MONITOR = null;
+    public static ImageConverterMBean IC_MBEAN = null;
 
     /**
      * IC_MONITOR
      */
-    public static IImageConverterMonitoring IC_MONITORING = null;
+    public static ImageConverterMonitoring IC_MONITOR = null;
 
 
     /**
