@@ -68,6 +68,7 @@ import org.im4java.process.ProcessStarter;
 import org.im4java.process.ProcessTask;
 import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.imageconverter.api.ImageConverterException;
 import com.openexchange.imageconverter.api.ImageFormat;
 import com.openexchange.imagetransformation.ScaleType;
@@ -78,7 +79,7 @@ import com.openexchange.imagetransformation.ScaleType;
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  * @since v7.10.0
  */
-class ImageProcessor {
+public class ImageProcessor {
 
 /* Debug class for simulating long running conversion tasks
  * To be used ionstead of ConvertCmd class, seetting an appropriate
@@ -110,22 +111,63 @@ class ImageProcessor {
     }
 */
 
+    /**
+     * {@link ImageProcessorStatus}
+     *
+     * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
+     * @since v7.10.1
+     */
+    public static class ImageProcessorStatus {
+
+        /**
+         * Initializes a new {@link ImageProcessorStatus}.
+         * @param isAvailable
+         * @param executablePath
+         * @param isGraphicsMagick
+         */
+        public ImageProcessorStatus(final String processorDescription, final boolean isAvailable) {
+            m_processorDescription = processorDescription;
+            m_isAvailable = isAvailable;
+        }
+
+        /**
+         * @return
+         */
+        public String getProcessorDescription() {
+            return m_processorDescription;
+        }
+
+        /**
+         * @return
+         */
+        public boolean isAvailable() {
+            return m_isAvailable;
+        }
+
+        // - Members -----------------------------------------------------------
+
+        final private String m_processorDescription;
+
+        final private boolean m_isAvailable;
+    }
+
     /**
      * Initializes a new {@link ImageProcessor}.
      */
-    ImageProcessor(@NonNull final String searchPath, boolean useGraphicsMagick) {
+    public ImageProcessor(@NonNull final String searchPath, boolean useGraphicsMagick, @Nullable String userComment) {
         super();
 
         ProcessStarter.setGlobalSearchPath(searchPath);
-        m_useGraphicsMagick = useGraphicsMagick;
 
-        implCheckAvailability(searchPath);
+        m_useGraphicsMagick = useGraphicsMagick;
+        m_imageProcessorStatus = implGetImageProcessorStatus(searchPath);
+        m_userComment = userComment;
     }
 
     /**
      *
      */
-    void shutdown() {
+    public void shutdown() {
         m_processExecutor.shutdownNow();
 
         try {
@@ -135,6 +177,13 @@ class ImageProcessor {
         }
     }
 
+    /**
+     * @return
+     */
+    public ImageProcessorStatus getStatus() {
+        return m_imageProcessorStatus;
+    }
+
     /**
      * @param inputFile
      * @param outputFile
@@ -142,7 +191,7 @@ class ImageProcessor {
      * @return
      * @throws ImageConverterException
      */
-    boolean scale(
+    public boolean scale(
         final File inputFile,
         @NonNull final File outputFile,
         @NonNull final ImageFormat imageFormat) throws ImageConverterException {
@@ -155,6 +204,11 @@ class ImageProcessor {
             final Integer imHeight = ImageConverterUtils.getIM4JExtent(imageFormat.getHeight());
             final ScaleType icScaleType = imageFormat.getScaleType();
 
+            // write user comment into target image, if set
+            if (null != m_userComment) {
+                imOp.comment(m_userComment);
+            }
+
             imOp.addImage();
 
             if (imageFormat.isAutoRotate()) {
@@ -248,7 +302,7 @@ class ImageProcessor {
                         try {
                             FileUtils.copyFile(inputFile, new File(ImageConverterConfig.IMAGECONVERTER_ERROR_PATH, inputFile.getName()));
                         } catch (Exception e1) {
-                            LOG.error("IC received Exception: " + Throwables.getRootCause(e1));
+                            LOG.error("IC received Exception: {}", Throwables.getRootCause(e1));
                         }
                     }
 
@@ -280,32 +334,43 @@ class ImageProcessor {
 
     // - Implementation --------------------------------------------------------
 
-    void implCheckAvailability(@NonNull final String searchPath) {
+    /**
+     * @param searchPath
+     * @return
+     */
+    ImageProcessorStatus implGetImageProcessorStatus(@NonNull final String searchPath) {
         File convertExecutable = new File("n/a");
+        boolean isAvailable = false;
 
         if (StringUtils.isNotBlank(searchPath)) {
-            m_isAvaible = (convertExecutable = new File(searchPath, "convert")).canExecute() &&
+            isAvailable = (convertExecutable = new File(searchPath, "convert")).canExecute() &&
                 (!m_useGraphicsMagick || (convertExecutable = new File(searchPath, "gm")).canExecute());
         }
 
-        if (!m_isAvaible && LOG.isErrorEnabled()) {
-            LOG.error(ImageConverterUtils.STR_BUILDER().
-                append("IC is not able to detect a valid ").
-                append(m_useGraphicsMagick ? "GraphicsMagick 'gm'" : "ImageMagick 'convert' ").
-                append("executable at configured search directory: ").append(searchPath).toString());
+        if (!isAvailable) {
+            if (LOG.isErrorEnabled()) {
+                LOG.error(ImageConverterUtils.STR_BUILDER().
+                    append("IC is not able to detect a valid ").
+                    append(m_useGraphicsMagick ? "GraphicsMagick 'gm'" : "ImageMagick 'convert' ").
+                    append("executable at configured search directory: ").append(searchPath).toString());
+            }
         } else if (LOG.isInfoEnabled()) {
             LOG.info(ImageConverterUtils.STR_BUILDER().
                 append("IC is using ").
                 append(m_useGraphicsMagick ? "GraphicsMagick 'gm'" : "ImageMagick 'convert' ").
                 append("executable located at: ").append(convertExecutable).toString());
         }
+
+        return new ImageProcessorStatus(isAvailable ? convertExecutable.getPath() : "n/a", isAvailable);
     }
 
     // - Members ---------------------------------------------------------------
 
-    private ProcessExecutor m_processExecutor = new ProcessExecutor();
+    final private ProcessExecutor m_processExecutor = new ProcessExecutor();
 
-    private boolean m_useGraphicsMagick = false;
+    final private boolean m_useGraphicsMagick;
 
-    private boolean m_isAvaible = false;
+    final private ImageProcessorStatus m_imageProcessorStatus;
+
+    final private String m_userComment;
 }
